# LAB3

lab3 is a redesign of the shared code repository. The core philosophy is to
centralize much of the analysis code that formerly lived in hard-to-maintain
scripts, and provide common frameworks to add new analysis methods. It's also
all in Python3! 

## Documentation

Tutorials for getting started, including installation instructions and the API 
reference, are available here:
https://losonczylab.gitlab.io/lab3/